@@ -24,8 +24,8 @@ class LineProfiler(Viewer):
     _model_name = Unicode('LineProfilerModel').tag(sync=True)
     _view_module = Unicode('itk-jupyter-widgets').tag(sync=True)
     _model_module = Unicode('itk-jupyter-widgets').tag(sync=True)
-    _view_module_version = Unicode('^0.12.2').tag(sync=True)
-    _model_module_version = Unicode('^0.12.2').tag(sync=True)
+    _view_module_version = Unicode('^0.16.0').tag(sync=True)
+    _model_module_version = Unicode('^0.16.0').tag(sync=True)
     point1 = NDArray(dtype=np.float64, default_value=np.zeros((3,), dtype=np.float64),
                 help="First point in physical space that defines the line profile")\
             .tag(sync=True, **array_serialization)\
@@ -43,6 +43,8 @@ class LineProfiler(Viewer):
             # select points
             if 'mode' not in kwargs:
                 kwargs['mode'] = 'z'
+        if 'ui_collapsed' not in kwargs:
+            kwargs['ui_collapsed'] = True
         super(LineProfiler, self).__init__(**kwargs)
 
 def line_profile(image, order=2, plotter=None, comparisons=None, **viewer_kwargs):
